@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-13 18:14:51
+@LastEditTime: 2021-09-13 18:49:27
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -551,7 +551,10 @@ class PropLogListHandler(SevenBaseHandler):
             condition += " AND create_date<=%s"
             params.append(end_date)
         if change_type > 0:
-            condition += " AND change_type=%s"
+            if change_type == 4:
+                condition += " AND change_type in(4,5,6)"
+            else:
+                condition += " AND change_type=%s"
             params.append(change_type)
 
         page_list, total = PropLogModel(context=self).get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
@@ -761,7 +764,7 @@ class GetPropGiveHandler(SevenBaseHandler):
         prop_log.act_id = act_id
         prop_log.open_id = open_id
         prop_log.user_nick = user_info.user_nick
-        prop_log.change_type = 4
+        prop_log.change_type = 5
         prop_log.operate_type = 0
         prop_log.prop_type = prop_give.prop_type
         prop_log.operate_value = 1
