@@ -2,18 +2,19 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-:LastEditTime: 2021-02-24 15:59:16
+:LastEditTime: 2021-04-15 15:12:43
 :LastEditors: HuangJingCan
 :description: 订单相关
 """
 from seven_cloudapp.handlers.seven_base import *
-from seven_cloudapp.models.seven_model import *
-from seven_cloudapp.libs.customize.seven import *
 
+from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp.models.db_models.pay.pay_order_model import *
 from seven_cloudapp.models.db_models.prize.prize_order_model import *
 
 from seven_cloudapp.handlers.server.order_s import PrizeOrderRemarksHandler
+from seven_cloudapp.handlers.server.order_s import PrizeOrderStatusHandler
+from seven_cloudapp.handlers.server.order_s import EndBoxOrderListHandler
 
 from seven_cloudapp_ppmt.models.db_models.prize.prize_roster_model import *
 
@@ -56,11 +57,11 @@ class PayOrderListHandler(SevenBaseHandler):
             condition += " AND user_nick LIKE %s"
             params.append(nick_name)
 
-        page_list, total = PayOrderModel().get_dict_page_list(field, page_index, page_size, condition, order_by="pay_date desc", params=params)
+        page_list, total = PayOrderModel(context=self).get_dict_page_list(field, page_index, page_size, condition, order_by="pay_date desc", params=params)
 
         page_info = PageInfo(page_index, page_size, total, page_list)
 
-        self.reponse_json_success(page_info)
+        return self.reponse_json_success(page_info)
 
 
 class PrizeOrderListHandler(SevenBaseHandler):
@@ -75,6 +76,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
         :return: 
         :last_editors: HuangJingCan
         """
+        order_type = int(self.get_param("order_type", 0))
         main_pay_order_no = self.get_param("main_pay_order_no")
         pay_order_no = self.get_param("pay_order_no")
         page_index = int(self.get_param("page_index", 0))
@@ -103,7 +105,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
             roster_condition += "order_no=%s"
             roster_params.append(pay_order_no)
         if roster_condition != "":
-            prize_roster_list = PrizeRosterModel().get_list(roster_condition, params=roster_params)
+            prize_roster_list = PrizeRosterModel(context=self).get_list(roster_condition, params=roster_params)
             if len(prize_roster_list) > 0:
                 condition += " and " + SevenHelper.get_condition_by_id_list("order_no", [i.prize_order_no for i in prize_roster_list])
         if order_no:
@@ -114,7 +116,7 @@ class PrizeOrderListHandler(SevenBaseHandler):
             params.append(user_nick)
         if real_name:
             condition += " AND real_name=%s"
-            params.append(user_nick)
+            params.append(real_name)
         if telephone:
             condition += " AND telephone=%s"
             params.append(telephone)
@@ -131,12 +133,15 @@ class PrizeOrderListHandler(SevenBaseHandler):
         if create_date_end:
             condition += " AND create_date<=%s"
             params.append(create_date_end)
+        if order_type > 0:
+            condition += " AND order_type=%s"
+            params.append(order_type)
 
-        page_list, total = PrizeOrderModel().get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
+        page_list, total = PrizeOrderModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
         if page_list:
             prize_roster_where = SevenHelper.get_condition_by_id_list("prize_order_no", [i["order_no"] for i in page_list])
-            prize_roster_dict_list = PrizeRosterModel().get_dict_list(prize_roster_where)
+            prize_roster_dict_list = PrizeRosterModel(context=self).get_dict_list(prize_roster_where)
             for i in range(0, len(prize_roster_dict_list)):
                 prize_roster_dict_list[i]["pay_order_no"] = prize_roster_dict_list[i]["order_no"]
 
@@ -144,9 +149,9 @@ class PrizeOrderListHandler(SevenBaseHandler):
 
             page_info = PageInfo(page_index, page_size, total, new_dict_list)
 
-            self.reponse_json_success(page_info)
+            return self.reponse_json_success(page_info)
         else:
-            self.reponse_json_success(PageInfo(page_index, page_size, total, page_list))
+            return self.reponse_json_success(PageInfo(page_index, page_size, total, page_list))
 
 
 class PrizeRosterListHandler(SevenBaseHandler):
@@ -165,6 +170,7 @@ class PrizeRosterListHandler(SevenBaseHandler):
         page_size = int(self.get_param("page_size", 10))
         act_id = int(self.get_param("act_id", 0))
         prize_order_id = int(self.get_param("prize_order_id", 0))
+        prize_order_no = self.get_param("prize_order_no")
         user_nick = self.get_param("nick_name")
         is_submit = int(self.get_param("is_submit", -1))
         order_status = int(self.get_param("order_status", -1))
@@ -178,6 +184,9 @@ class PrizeRosterListHandler(SevenBaseHandler):
         if prize_order_id > 0:
             condition += " AND prize_order_id=%s"
             params.append(prize_order_id)
+        if prize_order_no:
+            condition += " AND prize_order_no=%s"
+            params.append(prize_order_no)
         if user_nick:
             condition += " AND user_nick=%s"
             params.append(user_nick)
@@ -199,40 +208,11 @@ class PrizeRosterListHandler(SevenBaseHandler):
             condition += " AND open_id=%s"
             params.append(user_open_id)
 
-        page_list, total = PrizeRosterModel().get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
+        page_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
         page_info = PageInfo(page_index, page_size, total, page_list)
 
-        self.reponse_json_success(page_info)
-
-
-class PrizeOrderStatusHandler(SevenBaseHandler):
-    """
-    :description: 更新用户奖品订单状态
-    """
-    @filter_check_params("prize_order_id,order_status")
-    def post_async(self):
-        """
-        :description: 更新用户奖品订单状态
-        :param prize_order_id：奖品订单id
-        :param order_status：订单状态
-        :return: 
-        :last_editors: HuangJingCan
-        """
-        prize_order_id = int(self.get_param("prize_order_id", 0))
-        order_status = int(self.get_param("order_status", 0))
-        express_company = self.get_param("express_company")
-        express_no = self.get_param("express_no")
-
-        prize_order_model = PrizeOrderModel()
-        if order_status == 1:
-            update_sql = "order_status=1,express_company=%s,express_no=%s,deliver_date=%s,modify_date=%s"
-            params = [express_company, express_no, self.get_now_datetime(), self.get_now_datetime(), prize_order_id]
-            prize_order_model.update_table(update_sql, "id=%s", params)
-            self.reponse_json_success({"express_company": express_company, "express_no": express_no, "deliver_date": self.get_now_datetime()})
-        else:
-            prize_order_model.update_table("order_status=%s,modify_date=%s", "id=%s", [order_status, self.get_now_datetime(), prize_order_id])
-            self.reponse_json_success()
+        return self.reponse_json_success(page_info)
 
 
 class PrizeOrderExportHandler(SevenBaseHandler):
@@ -274,7 +254,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
             roster_condition += "order_no=%s"
             roster_params.append(pay_order_no)
         if roster_condition != "":
-            prize_roster_list = PrizeRosterModel().get_list(roster_condition, params=roster_params)
+            prize_roster_list = PrizeRosterModel(context=self).get_list(roster_condition, params=roster_params)
             if len(prize_roster_list) > 0:
                 condition += " and " + SevenHelper.get_condition_by_id_list("order_no", [i.prize_order_no for i in prize_roster_list])
         if order_no:
@@ -303,8 +283,8 @@ class PrizeOrderExportHandler(SevenBaseHandler):
             condition += " AND create_date<=%s"
             params.append(create_date_end)
 
-        prize_order_model = PrizeOrderModel()
-        prize_roster_model = PrizeRosterModel()
+        prize_order_model = PrizeOrderModel(context=self)
+        prize_roster_model = PrizeRosterModel(context=self)
 
         #奖品订单
         prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, order_by="create_date desc", params=params)
@@ -353,7 +333,7 @@ class PrizeOrderExportHandler(SevenBaseHandler):
 
                     data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"
 
-        self.reponse_json_success(data_text)
+        return self.reponse_json_success(data_text)
 
 
 class PrizeRosterListExportHandler(SevenBaseHandler):
@@ -387,8 +367,8 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
             params.append(order_status)
             condition += " AND order_status=%s"
 
-        prize_order_model = PrizeOrderModel()
-        prize_roster_model = PrizeRosterModel()
+        prize_order_model = PrizeOrderModel(context=self)
+        prize_roster_model = PrizeRosterModel(context=self)
 
         #奖品订单
         prize_roster_list, total = prize_roster_model.get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
@@ -420,7 +400,7 @@ class PrizeRosterListExportHandler(SevenBaseHandler):
                     data_row.append("已下单")
                 data_text = data_text + ",".join(list(map(lambda x: "\"" + x + "\"", data_row))) + "\n"
 
-        self.reponse_json_success(data_text)
+        return self.reponse_json_success(data_text)
 
 
 class PrizeOrderImportHandler(SevenBaseHandler):
@@ -440,7 +420,7 @@ class PrizeOrderImportHandler(SevenBaseHandler):
         act_id = self.get_param("act_id")
         content_json = self.json_loads(content)
 
-        prize_order_model = PrizeOrderModel()
+        prize_order_model = PrizeOrderModel(context=self)
 
         order_no_index = -1
         express_no_index = -1
@@ -479,4 +459,4 @@ class PrizeOrderImportHandler(SevenBaseHandler):
                 params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
                 prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
 
-        self.reponse_json_success()
\ No newline at end of file
+        return self.reponse_json_success()
\ No newline at end of file
